@@ -15,21 +15,9 @@ class TestToolbar(StartOpenLocalPageTestCaseBase):
 
     """Tests interaction with the toolbar."""
 
-    def test_reveal_chrome(self):
-        self.ensure_chrome_is_hidden()
-        self.reveal_chrome()
-        self.assert_chrome_eventually_shown()
-
-    def test_hide_chrome(self):
-        self.ensure_chrome_is_hidden()
-        self.reveal_chrome()
-        self.hide_chrome()
-        self.assert_chrome_eventually_hidden()
-
     def test_unfocus_chrome_hides_it(self):
-        webview = self.main_window.get_current_webview()
         self.ensure_chrome_is_hidden()
-        self.reveal_chrome()
-        self.pointing_device.move_to_object(webview)
-        self.pointing_device.click()
+        self.main_window.open_toolbar()
+        webview = self.main_window.get_current_webview()
+        self.pointing_device.click_object(webview)
         self.assert_chrome_eventually_hidden()
